==> switchyard-quickstart-distro-0.5.0.Beta1.zip: rules-interview/src/main/java/org/switchyard/quickstarts/rules/interview/InterviewRules.java <==
/* 
 * JBoss, Home of Professional Open Source 
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved. 
 * See the copyright.txt in the distribution for a 
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use, 
 * modify, copy, or redistribute it subject to the terms and conditions 
 * of the GNU Lesser General Public License, v. 2.1. 
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details. 
 * You should have received a copy of the GNU Lesser General Public License, 
 * v.2.1 along with this distribution; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 */
package org.switchyard.quickstarts.rules.interview;

import org.switchyard.component.common.rules.Mapping;
import org.switchyard.component.rules.Execute;
import org.switchyard.component.rules.Rules;

/**
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; (C) 2011 Red Hat Inc.
 */
@Rules(value=Interview.class,
       resources={"/org/switchyard/quickstarts/rules/interview/Interview.drl"},
       globals={@Mapping(expression="exchange.serviceName.localPart", variable="service")})
public interface InterviewRules extends Interview {

    @Override
    @Execute
    public void verify(Applicant applicant);

}

==> switchyard-quickstart-distro-0.6.0.Beta1.zip: rules-interview/src/main/java/org/switchyard/quickstarts/rules/interview/InterviewRules.java <==
/* 
 * JBoss, Home of Professional Open Source 
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved. 
 * See the copyright.txt in the distribution for a 
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use, 
 * modify, copy, or redistribute it subject to the terms and conditions 
 * of the GNU Lesser General Public License, v. 2.1. 
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details. 
 * You should have received a copy of the GNU Lesser General Public License, 
 * v.2.1 along with this distribution; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 */
package org.switchyard.quickstarts.rules.interview;

import org.switchyard.component.common.rules.Mapping;
import org.switchyard.component.rules.Execute;
import org.switchyard.component.rules.Rules;

/**
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; (C) 2011 Red Hat Inc.
 */
@Rules(value=Interview.class,
       resources={"/org/switchyard/quickstarts/rules/interview/Interview.drl"},
       globals={@Mapping(expression="exchange.provider.name.localPart", variable="service")})
public interface InterviewRules extends Interview {

    @Override
    @Execute
    public void verify(Applicant applicant);

}
